@@ -634,6 +634,25 @@ void HARNESS_EXPORT make_file_readonly(const std::string &file_name);
 
 void HARNESS_EXPORT check_file_access_rights(const std::string &file_name);
 
+/** @brief Copy contents of one file to another.
+ *
+ * Exception thrown if open, create read or write operation fails.
+ */
+void HARNESS_EXPORT copy_file(const std::string &from, const std::string &to);
+
+/**
+ * renames file.
+ *
+ * The function will overwrite the 'to' file if already exists.
+ *
+ * @param from old filename
+ * @param to   new filename
+ *
+ * @returns stdx::expected<void, std::error_code>
+ */
+stdx::expected<void, std::error_code> HARNESS_EXPORT
+rename_file(const std::string &from, const std::string &to);
+
 }  // namespace mysql_harness
 
 #endif /* MYSQL_HARNESS_FILESYSTEM_INCLUDED */
